/* 
 * linux/include/linux/hfs_fs_sb.h
 *
 * Copyright (C) 1995, 1996  Paul H. Hargrove
 * This file may be distributed under the terms of the GPL
 *
 * This file defines the type (struct hfs_sb_info) which contains the
 * HFS-specific information in in-core the superblock.
 */

#ifndef _HFS_FS_SB
#define _HFS_FS_SB

typedef int (*hfs_namein_fn) (char *, const unsigned char *);
typedef int (*hfs_nameout_fn) (char *, int, const char *);
typedef int (*hfs_ifill_fn) (struct inode *, void *, ino_t, ino_t);

/*
 * struct hfs_sb_info
 *
 * The HFS-specific part of a Linux (struct super_block)
 */
struct hfs_sb_info {
	struct buffer_head *	s_sbbh;		/* The buffer_head
						   holding the real
						   superblock (aka VIB
						   or MDB) */
	struct buffer_head *	s_bitmap[16];	/* The buffer_heads
						   holding the
						   allocation bitmap */
	struct hfs_super *	s_hs;		/* A pointer to the
						   data in s_sbbh */
	struct hfs_btree *	s_ext_tree;	/* Information about
						   the extents b-tree */
	struct hfs_btree *	s_cat_tree;	/* Information about
						   the catalog b-tree */
	int			s_quiet;	/* Silent failure 
						   when changing
						   owner or mode */
	hfs_namein_fn		s_namein;	/* The function used
						   to map Mac
						   filenames to Linux
						   filenames */
	hfs_nameout_fn		s_nameout;	/* The function used
						   to map Linux
						   filenames to Mac
						   filenames */
	hfs_ifill_fn		s_ifill;	/* The function used
						   to fill in inode
						   fields */
	__u32			s_file_count;	/* The number of
						   regular files in
						   the filesystem */
	__u32			s_dir_count;	/* The number of
						   directories in the
						   filesystem */
	__u32			s_next_id;	/* The next available
						   file id number */
	__u32			s_clump_size;	/* The number of bytes
						   to try to allocate
						   when extending a
						   file */
	__u32			s_write_count;	/* The number of
						   writes (a sort of
						   version number)
						   XXX: We don't yet
						   increment this */
	__u16			s_root_files;	/* The number of
						   regular
						   (non-directory)
						   files in the root
						   directory */
	__u16			s_root_dirs;	/* The number of
						   directories in the
						   root directory */
	__u16			s_fs_ablocks;	/* The number of
						   allocation blocks
						   in the filesystem */
	__u16			s_free_ablocks; /* The nuber of unused
						   allocation blocks
						   in the filesystem */
	__u16			s_alloc_blksz;	/* The number of
						   512-byte blocks per
						   "allocation block" */
	__u16			s_fs_start;	/* The first 512-byte
						   block represented
						   in the bitmap */
	__u16			s_umask;	/* The umask applied
						   to the permissions
						   on all files */
	uid_t			s_uid;		/* The uid to assign
						   to all files */
	gid_t			s_gid;		/* The gid to assign
						   to all files */
};

#endif
